fetch_profile_secrets

Function fetch_profile_secrets 

async fn fetch_profile_secrets(
    client: &BusClient,
    profile: &TrustProfileName,
    prefix: Option<&str>,
) -> Result<Vec<(String, Vec<u8>)>>
Fetch all secrets for a profile from the vault via IPC.

Returns sanitized env var name/value pairs. Secrets that map to denied env var names are skipped with a warning on stderr.