fn needs_privilege(path: &Path) -> bool
Check if creating a path requires privilege escalation.
Walks up the directory tree to find the first existing ancestor and checks if it is owned by the current user.